@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1998-2001 The Free Software Foundation
+ * Copyright (C) 1998-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Michael Lausch <michael@lausch.at>
@@ -59,18 +59,6 @@ static GObjectClass *parent_class = NULL;
  * Callbacks
  */
 
-static void
-dialog_response_cb (GtkDialog *dialog, gint response_id, gpointer user_data)
-{
-	g_return_if_fail (GNOME_DB_IS_ERROR_DIALOG (dialog));
-
-	switch (response_id) {
-	case GTK_RESPONSE_CLOSE :
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-		break;
-	}
-}
-
 /*
  * GnomeDbErrorDialog class implementation
  */
@@ -120,9 +108,6 @@ gnome_db_error_dialog_init (GnomeDbErrorDialog *dialog, GnomeDbErrorDialogClass
 	dialog->priv = g_new (GnomeDbErrorDialogPrivate, 1);
 	dialog->priv->title = NULL;
 
-	g_signal_connect (G_OBJECT (dialog), "response",
-			  G_CALLBACK (dialog_response_cb), NULL);
-
 	/* create the error viewer */
 	dialog->priv->error_widget = GNOME_DB_ERROR (gnome_db_error_new ());
 	gtk_widget_show (GTK_WIDGET (dialog->priv->error_widget));
@@ -239,8 +224,8 @@ gnome_db_error_dialog_show_errors (GnomeDbErrorDialog *dialog,
 	case GTK_RESPONSE_NO :
 		gnome_db_error_next (GNOME_DB_ERROR (dialog->priv->error_widget));
 		break;
-	case GTK_RESPONSE_CANCEL :
-		gtk_widget_destroy (dialog);
+	case GTK_RESPONSE_CLOSE :
+		gtk_widget_destroy (GTK_WIDGET (dialog));
 	}
 }
 
