@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001, The Free Software Foundation
+ * Copyright (C) 1999-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -22,7 +22,9 @@
 
 #include <libgnomedb/gnome-db-grid.h>
 #include <libgnomedb/gnome-db-util.h>
+#include <libgnomedb/gnome-db-model.h>
 #include <gobject/gmarshal.h>
+#include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeview.h>
 #include "libgnomedb-private.h"
 
@@ -298,12 +300,111 @@ gnome_db_grid_set_model (GnomeDbGrid *grid, GdaDataModel *model)
 
 	/* redisplay the GtkTreeView */
 	gtk_widget_destroy (grid->priv->tree_view);
-	grid->priv->tree_view = gnome_db_model_to_gtk_tree_view (grid->priv->model);
+	grid->priv->tree_view = GTK_WIDGET (gnome_db_model_to_gtk_tree_view (grid->priv->model));
 	gtk_container_add (GTK_CONTAINER (grid->priv->scroll), grid->priv->tree_view);
 	gtk_widget_show (grid->priv->tree_view);
 	setup_grid (grid);
 }
 
+static void
+foreach_selected_cb (GtkTreeModel *tree_model,
+		     GtkTreePath *path,
+		     GtkTreeIter *iter,
+		     gpointer user_data)
+{
+	DataModelInfo *iter_info;
+	GList **list = (GList **) user_data;
+
+	gtk_tree_model_get (tree_model, iter, 0, &iter_info, -1);
+	if (iter_info)
+		*list = g_list_append (*list, GINT_TO_POINTER (iter_info->row));
+}
+
+/**
+ * gnome_db_grid_get_selection
+ * @grid: a #GnomeDbGrid widget.
+ *
+ * Returns the list of the currently selected rows in a
+ * #GnomeDbGrid widget. The returned value is a list of integers,
+ * which represent each of the selected rows.
+ *
+ * Returns: a GList of integers. This list should be freed (by calling
+ * #g_list_free) when no longer needed.
+ */
+GList *
+gnome_db_grid_get_selection (GnomeDbGrid *grid)
+{	
+	GtkTreeSelection *selection;
+	GList *list = NULL;
+
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), NULL);
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (grid->priv->tree_view));
+	gtk_tree_selection_selected_foreach (
+		selection,
+		(GtkTreeSelectionForeachFunc) foreach_selected_cb,
+		&list);
+
+	return list;
+}
+
+/**
+ * gnome_db_grid_select_all
+ */
+void
+gnome_db_grid_select_all (GnomeDbGrid *grid)
+{
+	GtkTreeSelection *selection;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (grid->priv->tree_view));
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
+	gtk_tree_selection_select_all (selection);
+}
+
+/**
+ * gnome_db_grid_unselect_all
+ */
+void
+gnome_db_grid_unselect_all (GnomeDbGrid *grid)
+{
+	GtkTreeSelection *selection;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (grid->priv->tree_view));
+	gtk_tree_selection_unselect_all (selection);
+}
+
+/**
+ * gnome_db_grid_get_selection_mode
+ */
+GtkSelectionMode
+gnome_db_grid_get_selection_mode (GnomeDbGrid *grid)
+{
+	GtkTreeSelection *selection;
+
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), GTK_SELECTION_NONE);
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (grid->priv->tree_view));
+	return gtk_tree_selection_get_mode (selection);
+}
+
+/**
+ * gnome_db_set_selection_mode
+ */
+void
+gnome_db_grid_set_selection_mode (GnomeDbGrid *grid, GtkSelectionMode mode)
+{
+	GtkTreeSelection *selection;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (grid->priv->tree_view));
+	gtk_tree_selection_set_mode (selection, mode);
+}
+
 /**
  * gnome_db_grid_hide_column_titles
  */
