@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001 The Free Software Foundation
+ * Copyright (C) 1999-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -50,15 +50,21 @@ struct _GnomeDbGridClass {
 	void (* row_unselected) (GnomeDbGrid *grid);
 };
 
-GType         gnome_db_grid_get_type (void);
-GtkWidget    *gnome_db_grid_new (void);
-GtkWidget    *gnome_db_grid_new_with_model (GdaDataModel *model);
+GType            gnome_db_grid_get_type (void);
+GtkWidget       *gnome_db_grid_new (void);
+GtkWidget       *gnome_db_grid_new_with_model (GdaDataModel *model);
 
-GdaDataModel *gnome_db_grid_get_model (GnomeDbGrid *grid);
-void          gnome_db_grid_set_model (GnomeDbGrid *grid, GdaDataModel *model);
+GdaDataModel    *gnome_db_grid_get_model (GnomeDbGrid *grid);
+void             gnome_db_grid_set_model (GnomeDbGrid *grid, GdaDataModel *model);
+GList           *gnome_db_grid_get_selection (GnomeDbGrid *grid);
+void             gnome_db_grid_select_all (GnomeDbGrid *grid);
+void             gnome_db_grid_unselect_all (GnomeDbGrid *grid);
+GtkSelectionMode gnome_db_grid_get_selection_mode (GnomeDbGrid *grid);
+void             gnome_db_grid_set_selection_mode (GnomeDbGrid *grid,
+						   GtkSelectionMode mode);
 
-void          gnome_db_grid_hide_column_titles (GnomeDbGrid *grid);
-void          gnome_db_grid_show_column_titles (GnomeDbGrid *grid);
+void             gnome_db_grid_hide_column_titles (GnomeDbGrid *grid);
+void             gnome_db_grid_show_column_titles (GnomeDbGrid *grid);
 
 G_END_DECLS
 
