@@ -1,5 +1,8 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001 Rodrigo Moya
+ * Copyright (C) 1999-2002 The GNOME Foundation.
+ *
+ * AUTHORS:
+ * 	Rodrigo Moya <rodrigo@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -18,9 +21,11 @@
  */
 
 #include <bonobo/bonobo-i18n.h>
-#include <libgda/libgda.h>
 #include <bonobo/bonobo-ui-main.h>
+#include <glade/glade-init.h>
+#include <libgda/libgda.h>
 #include <libgnomeui/gnome-ui-init.h>
+#include <libgnomedb/libgnomedb.h>
 
 void
 gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *args[])
@@ -37,6 +42,8 @@ gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *arg
 
 	if (!bonobo_ui_is_initialized ())
 		bonobo_ui_init (app_id, version, &nargs, args);
+
+	glade_init ();
 }
 
 typedef struct {
