@@ -1,5 +1,8 @@
 /* GNOME DB library
- * Copyright (C) 1999-2000 Rodrigo Moya
+ * Copyright (C) 1999-2002 The GNOME Foundation.
+ *
+ * AUTHORS:
+ * 	Rodrigo Moya <rodrigo@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -19,6 +22,7 @@
 
 #include <libgnomedb/gnome-db-model.h>
 #include <libgnomedb/gnome-db-util.h>
+#include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkliststore.h>
 #include <gtk/gtktreeview.h>
 #include <gtk/gtktreeviewcolumn.h>
@@ -67,6 +71,53 @@ data_model_info_get_type (void)
 	return type;
 }
 
+static gint
+sort_values (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointer user_data)
+{
+	DataModelInfo *infoa, *infob;
+	const GdaValue *valuea, *valueb;
+	gint retval = 1;
+
+	gtk_tree_model_get (model, itera, 0, &infoa, -1);
+	gtk_tree_model_get (model, iterb, 0, &infob, -1);
+	if (!infoa || !infob)
+		return 0;
+
+	valuea = gda_data_model_get_value_at (infoa->model,
+					      GPOINTER_TO_INT (user_data),
+					      infoa->row);
+	valueb = gda_data_model_get_value_at (infob->model,
+					      GPOINTER_TO_INT (user_data),
+					      infob->row);
+	if (!valuea || !valueb)
+		return 0;
+
+	/* compare values */
+	if (gda_value_isa ((GdaValue *) valuea, GDA_VALUE_TYPE_NULL) &&
+	    gda_value_isa ((GdaValue *) valueb, GDA_VALUE_TYPE_NULL))
+		retval = 0;
+	else if (gda_value_isa ((GdaValue *) valuea, GDA_VALUE_TYPE_BIGINT) &&
+		 gda_value_isa ((GdaValue *) valueb, GDA_VALUE_TYPE_BIGINT)) {
+		if (gda_value_get_bigint ((GdaValue *) valuea) >
+		    gda_value_get_bigint ((GdaValue *) valueb))
+			retval = -1;
+	}
+	else {
+		gchar *stra, *strb;
+
+		/* data types don't match, so use strings to sort */
+		stra = gda_value_stringify ((GdaValue *) valuea);
+		strb = gda_value_stringify ((GdaValue *) valueb);
+		retval = strcmp (stra, strb);
+
+		g_free (stra);
+		g_free (strb);
+	}
+
+	return retval;
+
+}
+
 /*
  * Callbacks
  */
@@ -79,7 +130,7 @@ value_set_func (GtkTreeViewColumn *tree_column,
                 gpointer user_data)
 {
 	DataModelInfo *info = NULL;
-	GdaValue *value;
+	const GdaValue *value;
 	gchar *txt;
 
 	gtk_tree_model_get (model, iter, 0, &info, -1);
@@ -92,7 +143,7 @@ value_set_func (GtkTreeViewColumn *tree_column,
 	if (!value)
 		return;
 
-	txt = gda_value_stringify (value);
+	txt = gda_value_stringify ((GdaValue *) value);
 	g_object_set (G_OBJECT (cell), "text", txt, NULL);
 
 	g_free (txt);
@@ -124,23 +175,38 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 	}
 
 	/* create the tree view widget */
-	tree_view = gnome_db_new_tree_view_widget (GTK_TREE_MODEL (tree_model));
+	tree_view = GTK_TREE_VIEW (gnome_db_new_tree_view_widget (
+					   GTK_TREE_MODEL (tree_model)));
 	g_object_unref (G_OBJECT (tree_model));
 
 	text_renderer = gtk_cell_renderer_text_new ();
 
 	col_count = gda_data_model_get_n_columns (model);
 	for (i = 0; i < col_count; i++) {
+		GtkTreeViewColumn *column;
+
 		gtk_tree_view_insert_column_with_data_func (
 			GTK_TREE_VIEW (tree_view),
-			-1,
-			gda_data_model_get_column_title (model, i),
+			i,
+			(gchar *) gda_data_model_get_column_title (model, i),
 			text_renderer,
 			value_set_func,
 			GINT_TO_POINTER (i),
 			NULL);
+
+		column = gtk_tree_view_get_column (GTK_TREE_VIEW (tree_view), i);
+		gtk_tree_view_column_set_resizable (column, TRUE);
+		gtk_tree_view_column_set_clickable (column, TRUE);
+		gtk_tree_view_column_set_reorderable (column, TRUE);
+
+		gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (tree_model),
+						 i, sort_values,
+						 GINT_TO_POINTER (i),
+						 NULL);
 	}
 
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (tree_model),
+					      0, GTK_SORT_ASCENDING);
 	gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW (tree_view), TRUE);
 
 	return tree_view;
