@@ -1,5 +1,8 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001 Rodrigo Moya
+ * Copyright (C) 1999-2002 The GNOME Foundation.
+ *
+ * AUTHORS:
+ * 	Rodrigo Moya <rodrigo@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -22,6 +25,7 @@
 
 #include <libgda/libgda.h>
 #include <libgnomedb/gnome-db-browser.h>
+#include <libgnomedb/gnome-db-combo.h>
 #include <libgnomedb/gnome-db-connection-selector.h>
 #include <libgnomedb/gnome-db-control.h>
 #include <libgnomedb/gnome-db-control-widget.h>
